@@ -112,7 +112,8 @@ class client:
             elif Response.split(',')[0] == "color":
                 print("hi")
                 Color = Response.split(',')[1]
-                self.client_instance.set_player(Player(player_name, Color))
+                screen_num=Response.split(',')[2]
+                self.client_instance.set_player(Player(player_name, Color, screen_num))
                 print(Color)
             elif Response.split(',')[0] == "bank":
                 arr = [int(x) for x in Response.split(',')[1:]]
