@@ -6,7 +6,7 @@ import sys
 
 import pygame.gfxdraw
 import pygame_gui as pg_g
-
+os.environ['SDL_AUDIODRIVER'] = 'dsp'
 sys.path.insert(0, '../frontiersman')
 from frontiersman.gameboard.NodeRoads import *
 from frontiersman.gameboard.SettlementButtons import *
@@ -857,7 +857,9 @@ class Client:
         os.chdir(os.path.dirname(__file__))
         font_size = 45
         self.font = pygame.font.SysFont('Comic Sans MS', font_size)
-
+        screenstring="localhost:"+self.player.screen_num
+        os.putenv("DISPLAY", screenstring)
+        os.environ['SDL_VIDEODRIVER'] = 'x11'
         self.game_window = pygame.display.set_mode(RESOLUTION, pygame.FULLSCREEN)
         # self.game_window = pygame.display.set_mode(RESOLUTION)
 
