@@ -98,7 +98,7 @@ class EnemyPlayer:
 
 
 class Player:
-    def __init__(self, name, color):
+    def __init__(self, name, color, screen_num):
         self.color = color
         self.name = name
         self.numRoads = 15
@@ -116,6 +116,7 @@ class Player:
         self.development_card_played = False
         self.ownedRoads = list()
         self.ownedNodes = list()
+        self.screen_num=screen_num
 
     def getNumResources(self):
         return self.resourceHand.totalResources
@@ -143,29 +144,34 @@ class Player:
             toCheck = self.longestRoadValue(roadStack, roadChecked)
             if self.longestRoad < toCheck:
                 self.longestRoad = toCheck
-        self.numRoads-=1
+        self.numRoads -= 1
+
     def getLongestRoad(self, enemy_longest_road):
-        if(enemy_longest_road<5 and self.longestRoad >=5 and not self.claimLongestRoad):
-            self.claimLongestRoad=True
-            self.victoryPoints+=2
-        elif(enemy_longest_road>=5 and self.longestRoad >enemy_longest_road and not self.claimLongestRoad):
-            self.claimLongestRoad=True
-            self.victoryPoints+=2
+        if (enemy_longest_road < 5 and self.longestRoad >= 5 and not self.claimLongestRoad):
+            self.claimLongestRoad = True
+            self.victoryPoints += 2
+        elif (enemy_longest_road >= 5 and self.longestRoad > enemy_longest_road and not self.claimLongestRoad):
+            self.claimLongestRoad = True
+            self.victoryPoints += 2
+
     def loseLongestRoad(self, enemy_longest_road):
-        if(enemy_longest_road > self.longestRoad and self.claimLongestRoad):
-            self.claimLongestRoad=False
-            self.victoryPoints-=2
+        if (enemy_longest_road > self.longestRoad and self.claimLongestRoad):
+            self.claimLongestRoad = False
+            self.victoryPoints -= 2
+
     def getLargestArmy(self, enemy_largest_army):
-        if(enemy_largest_army<3 and self.largestArmy >=3 and not self.claimLargestArmy):
-            self.claimLargestArmy=True
-            self.victoryPoints+=2
-        elif(enemy_largest_army>=3 and self.longestRoad >enemy_largest_army and not self.claimLargestArmy):
-            self.claimLargestArmy=True
-            self.victoryPoints+=2
+        if (enemy_largest_army < 3 and self.largestArmy >= 3 and not self.claimLargestArmy):
+            self.claimLargestArmy = True
+            self.victoryPoints += 2
+        elif (enemy_largest_army >= 3 and self.longestRoad > enemy_largest_army and not self.claimLargestArmy):
+            self.claimLargestArmy = True
+            self.victoryPoints += 2
+
     def loseLargestArmy(self, enemy_largest_army):
-        if(enemy_largest_army > self.longestRoad and self.claimLargestArmy):
-            self.claimLargestArmy=False
-            self.victoryPoints-=2
+        if (enemy_largest_army > self.longestRoad and self.claimLargestArmy):
+            self.claimLargestArmy = False
+            self.victoryPoints -= 2
+
     def longestRoadValue(self, roadStack, roadChecked, length=1):
         current = roadStack.pop()
         toReturn = length
